@@ -59,7 +59,15 @@ describe 'trove::client' do
         when 'Debian'
           { :client_package_name => 'python3-troveclient' }
         when 'RedHat'
-          { :client_package_name => 'python-troveclient' }
+          if facts[:operatingsystem] == 'Fedora'
+            { :client_package_name => 'python3-troveclient' }
+          else
+            if facts[:operatingsystemmajrelease] > '7'
+              { :client_package_name => 'python3-troveclient' }
+            else
+              { :client_package_name => 'python-troveclient' }
+            end
+          end
         end
       end
 
